%-------------------------------------------------------------------------------
% Template class for NA61 documents 
%
% Based on ATLAS preprint class by Ian Brock (ian.brock@cern.ch)
%
%-------------------------------------------------------------------------------
\def\SHINEPackageVersion{02-00-01}

\ProvidesClass{na61doc}[2016/10/10 v.02-00-01 NA61 document class]
% Needs 2009 TeX Live or later
%\NeedsTeXFormat{LaTeX2e}[2009/01/01]

\RequirePackage{xspace}
%-------------------------------------------------------------------------------
% More advanced if syntax
\RequirePackage{ifthen}
% Process options. Use kvoptions package.
\RequirePackage{kvoptions}
%\RequirePackage[debugshow]{kvoptions}
\SetupKeyvalOptions{
  family=ADOC,
  prefix=ADOC@
}
\DeclareBoolOption[true]{nasixtyonestyle}
\DeclareBoolOption[false]{coverpage}
\DeclareBoolOption[false]{cernpreprint}
\DeclareBoolOption[false]{preprint}
\DeclareBoolOption[true]{NOTE}
\DeclareBoolOption[false]{PAPER}
\DeclareBoolOption[false]{CONF}
\DeclareBoolOption[false]{PUB}
\DeclareBoolOption[false]{BOOK}
\DeclareBoolOption[false]{auxmat}
\DeclareStringOption[2013]{texlive}
\DeclareStringOption{paper}
\DeclareBoolOption[true]{newtx}
\DeclareBoolOption[true]{txfonts}
\DeclareBoolOption[false]{libertine}
\DeclareBoolOption[false]{palatino}
\DeclareBoolOption[true]{floatopt}
\DeclareBoolOption[false]{texmf}
\DeclareBoolOption[false]{showframe}
\DeclareStringOption[0pt]{titleextraheight}
\DeclareStringOption[0pt]{copyrightoffset}
\ProcessKeyvalOptions{ADOC}
\RequirePackage{amsmath}
% Standard LaTeX options for paper size
%\newif\ifADOC@aivpaper
%\ADOC@aivpapertrue
%\DeclareOption{a4paper}{\PassOptionsToClass{\CurrentOption}{\ADOC@mainclass}} % \ADOC@aivpapertrue} %\def\ADOC@paperstring{a4paper}}
%\DeclareOption{letterpaper}{\PassOptionsToClass{\CurrentOption}{\ADOC@mainclass}} % \ADOC@aivpaperfalse} %\def\ADOC@paperstring{letterpaper}}
%\ProcessOptions\relax
\newcommand*{\SHINETeXLiveVersion}{\ADOC@texlive}
\newcommand{\NASixtyOne}{NA61\slash SHINE\xspace}%this seems to work properly to me. aa

\newif\ifADOC@CONFnote
\newif\ifADOC@PUBnote

% CERN preprint or auxiliary material
\ifADOC@cernpreprint
  \ADOC@auxmatfalse
\else
  \ifADOC@preprint
    \ADOC@cernpreprinttrue
    \ADOC@auxmatfalse
  \else
    \ifADOC@auxmat
      \ADOC@cernpreprintfalse
      \ADOC@auxmattrue
    \fi
  \fi
\fi

% Directory for style files
\ifADOC@texmf
  \providecommand*{\SHINELATEXPATH}{}
\else
  \providecommand*{\SHINELATEXPATH}{}
\fi

% Type of document
\newcommand*{\ADOC@docheadingdefault}{}
\ifADOC@PAPER
  \typeout{na61doc: NA61/SHINE paper}
  \renewcommand*{\ADOC@docheadingdefault}{NA61/SHINE Paper}
  \ADOC@PAPERtrue
  \ADOC@NOTEfalse
  \ADOC@CONFnotefalse
  \ADOC@PUBnotefalse
  \ADOC@BOOKfalse
\else
  \ifADOC@CONF
    \typeout{na61doc: NA61/SHINE CONF note}
    \renewcommand*{\ADOC@docheadingdefault}{NA61/SHINE CONF Note}
    \ADOC@PAPERfalse
    \ADOC@NOTEfalse
    \ADOC@CONFnotetrue
    \ADOC@PUBnotefalse
    \ADOC@BOOKfalse
  \else
    \ifADOC@PUB
      \typeout{na61doc: NA61/SHINE PUB note}
      \renewcommand*{\ADOC@docheadingdefault}{NA61/SHINE PUB Note}
      \ADOC@PAPERfalse
      \ADOC@NOTEfalse
      \ADOC@CONFnotefalse
      \ADOC@PUBnotetrue
      \ADOC@BOOKfalse
    \else
      \ifADOC@BOOK
        \typeout{na61doc: NA61/SHINE BOOK}
        \ADOC@PAPERfalse
        \ADOC@NOTEfalse
        \ADOC@CONFnotefalse
        \ADOC@PUBnotefalse
        \ADOC@BOOKtrue
      \else
        \typeout{na61doc: NA61/SHINE Note}
        \renewcommand*{\ADOC@docheadingdefault}{NA61/SHINE Note}
      \fi
    \fi
  \fi
\fi

% Decide on the main class
\ifADOC@BOOK
  \typeout{na61doc: use KOMA-script scrbook class}
  \def\ADOC@mainclass{scrbook}
\else
  \typeout{na61doc: use KOMA-script scrartcl class}
  \def\ADOC@mainclass{scrartcl}
\fi

% Set paper size
\ifx\ADOC@paper\@empty
  \def\ADOC@paperstring{a4paper}
  \PassOptionsToClass{a4paper}{\ADOC@mainclass}
  \typeout{na61doc: paper size set to default A4}
\else
  \def\ADOC@paperstring{\ADOC@paper paper}
  \PassOptionsToClass{\ADOC@paperstring}{\ADOC@mainclass}
  \typeout{na61doc: paper is \ADOC@paper, string for class is \ADOC@paperstring}
\fi

% Switch to txfonts for TeX Live <= 2012
% Need to pass this option to na61package as well
\ifthenelse{\ADOC@texlive < 2012 \AND \boolean{ADOC@newtx}}{%
  \typeout{*** na61doc: use txfonts instead of newtx}
  \ADOC@newtxfalse
  \ADOC@txfontstrue
  \PassOptionsToPackage{txfonts}{\SHINELATEXPATH na61package}
}{%
}

%-------------------------------------------------------------------------------
% Defaults for title page
\newdimen\ADOC@skipbeforetitle
\ADOC@skipbeforetitle=60\p@
\newcommand{\skipbeforetitle}[1]{\ADOC@skipbeforetitle=#1}

\def\@title{Dummy title in na61doc\\ Use \textbackslash ShineTitle to set it}
\newcommand{\ShineTitleText}{Dummy ShineTitleText in na61doc\\ Use \textbackslash ShineTitle to set it}
\newcommand{\ShineTitle}[1]{%
  \def\@title{#1}%
  \renewcommand{\ShineTitleText}{#1}%
}
\def\@author{The NA61/SHINE Collaboration}
\def\@date{\today}

% Draft version 
\def\ADOC@draftversion{}
\newcommand*{\draftversion}[1]{\def\ADOC@draftversion{#1}}
\newcommand*{\ShineVersion}[1]{\def\ADOC@draftversion{#1}}

% SHINE reference code - empty by default
% Also create variable with web page
\def\ADOC@refcode{}
\newcommand*{\ShineRefCode}[1]{\def\ADOC@refcode{#1}}
\newcommand*{\ShinePaperWebpage}{http://shine.web.cern.ch/\ADOC@refcode}

% NA61 note number
\def\ADOC@shinenote{}
\newcommand*{\ShineNote}[1]{\def\ADOC@shinenote{#1}}

% SHINE date - arXiv submission; to be filled in by the Physics Office
\def\ADOC@shinedate{\today}
\newcommand*{\ShineDate}[1]{\def\ADOC@shinedate{#1}}

% Journal
\def\ADOC@journal{}
\newcommand*{\journal}[1]{\def\ADOC@journal{#1}}
\newcommand*{\ShineJournal}[1]{\def\ADOC@journal{#1}}

% Preprint
\def\ADOC@preprintnumber{}
\newcommand*{\PreprintIdNumber}[1]{\def\ADOC@preprintnumber{#1}}

% Journal
\def\ADOC@journalref{}
\newcommand*{\ShineJournalRef}[1]{\def\ADOC@journalref{#1}}

% DOI
\def\ADOC@doi{}
\newcommand*{\ShineDOI}[1]{\def\ADOC@doi{#1}}

% Shine document heading
\def\ADOC@docheading{}
\newcommand*{\ShineHeading}[1]{\def\ADOC@docheading{#1}}

% arXiv
\def\ShineArXivId{}
\def\ShineArXivURL{}
\newcommand*{\arXivId}[1]{\def\ShineArXivId{#1}\def\ShineArXivURL{http://arXiv.org/abs/#1}}
\newcommand*{\ShineArXivCat}{[hep-ex]}

% HEP Data
\def\ShineHepDataRecord{}
\newcommand*{\HepDataRecord}[1]{\def\ShineHepDataRecord{http://hepdata.cedar.ac.uk/view/ins#1}}

% Submission details
\def\ADOC@subprepend{To be submitted to:}
\newcommand*{\subprepend}[1]{\def\ADOC@subprepend{#1}}

% Abstract text
\def\ShineAbstractText{}
\newcommand{\ShineAbstract}[1]{\def\ShineAbstractText{#1}}
\newcommand{\abstracttext}[1]{\def\ShineAbstractText{#1}}

%-------------------------------------------------------------------------------
% Invoke main class
% Note that \KOMAoptions is not available in versions of KOMA-Script older than 3.0
\ifADOC@BOOK
  \LoadClass[titlepage,11pt]{scrbook}
  %\LoadClass[titlepage,11pt,twoside=semi]{scrbook}
\else
  \LoadClass[titlepage,11pt]{scrartcl}
  %\LoadClass[titlepage,11pt,twoside=semi]{scrartcl}
\fi

% Turn on bold math when using \bfseries
\def\bfseries{\fontseries\bfdefault\selectfont\boldmath}

% Set KOMA-script options for SHINE style
  \KOMAoptions{headinclude=true, footinclude=false}
  % Put less text on the pages of BOOKs etc.
  \ifADOC@BOOK
    \KOMAoptions{DIV=12, BCOR=5mm, twoside}
  \else
    \KOMAoptions{DIV=14, BCOR=5mm}
  \fi
  % Do not put a dot after Section/Chapter, nor in the figure caption.
  %\KOMAoptions{numbers=noendperiod}
  % Paragraph spacing is half a line
  \KOMAoptions{parskip=half}
  \addtokomafont{disposition}{\rmfamily}
  \addtokomafont{part}{\LARGE}
  \addtokomafont{descriptionlabel}{\rmfamily}
  %\setkomafont{pageheadfoot}{\normalsize\sffamily}
  \setkomafont{pagehead}{\normalsize\rmfamily}
  %\setkomafont{publishers}{\normalsize\rmfamily}
  \setkomafont{caption}{\normalfont\small}
  \setcapindent{0pt}
  \deffootnote[1em]{1em}{1em}{\textsuperscript{\thefootnotemark}\ }

% SHINE draft cover pages for papers, PUB and CONF notes
\def\ADOC@shinecover{\SHINELATEXPATH shinecover}
\ifADOC@coverpage
  \typeout{na61doc: load shinecover package}
  \ifADOC@CONFnote
    \PassOptionsToPackage{CONF,na61doc}{\ADOC@shinecover}
  \else
    \ifADOC@PUBnote
      \PassOptionsToPackage{PUB,na61doc}{\ADOC@shinecover}
    \else
      \PassOptionsToPackage{na61doc}{\ADOC@shinecover}
    \fi
  \fi
  \RequirePackage{\ADOC@shinecover}
\fi

% Remove the numbers from all the headings (\section, \subsection, etc.)
%\setcounter{secnumdepth}{-1}

% Required packages
\RequirePackage{graphicx}
%\RequirePackage{xcolor}
\RequirePackage{babel}
% hyperref is needed in many places, so include it here

% Font(s)
\ifADOC@txfonts
  % Needs special amsmath code in shinepackage
  \typeout{na61doc: using txfonts}
  \RequirePackage[varg]{txfonts}
  \RequirePackage[T1]{fontenc}
\else
  \ifADOC@libertine
    \typeout{na61doc: using Libertine fonts}
    \RequirePackage{libertine}
    \RequirePackage[T1]{fontenc}
    \RequirePackage[libertine]{newtxmath}
  \else
    \ifADOC@palatino
      \typeout{na61doc: using Palatino fonts}
      % Palatino for rm and math | Helvetica for ss | Courier for tt
      \RequirePackage{mathpazo} % math & rm
      \linespread{1.05}        % Palatino needs more leading (space between lines)
      \RequirePackage[scaled]{helvet} % ss
      \RequirePackage{courier} % tt
      \normalfont
      \RequirePackage[T1]{fontenc}
    \else
      \typeout{na61doc: using newtx fonts package}
      \RequirePackage{newtxtext}
      \ifthenelse{\ADOC@texlive < 2013}{%
        \typeout{*** na61doc: include amsmath before newtxmath}
        \RequirePackage{amsmath}
      }{%
      }
      \RequirePackage{newtxmath}
    \fi
  \fi
\fi

% Adjust float settings to try to avoid problems.
% These follow the UK FAQ - see also P.199-200 of the LaTeX Book
\ifADOC@floatopt
  \renewcommand{\topfraction}{0.85}
  \renewcommand{\bottomfraction}{0.70}
  \renewcommand{\textfraction}{0.15}
  \renewcommand{\floatpagefraction}{0.66}
  \renewcommand{\dbltopfraction}{0.66}
  \renewcommand{\dblfloatpagefraction}{0.66}
  \setcounter{topnumber}{9}
  \setcounter{bottomnumber}{9}
  \setcounter{totalnumber}{20}
\fi

% Add ability to include line numbers
\RequirePackage{lineno}
% If you have an old lineno or do not have it, you can get it from the latex/other directory
% \RequirePackage{latex/other/lineno}
% \nolinenumbers
\ifADOC@showframe
  \RequirePackage{showframe}
\fi

% Compute the time in hours and minutes; make new variables \timehh and \timemm
\newcount\timehh\newcount\timemm
\timehh=\time 
\divide\timehh by 60 \timemm=\time
\count255=\timehh\multiply\count255 by -60 \advance\timemm by \count255
% Now make a string with date and time
\newcommand{\dateandtime}{\today \ --
  \ifnum\timehh<10 0\fi\number\timehh:\ifnum\timemm<10 0\fi\number\timemm}
% \RequirePackage{scrdate,scrtime}

% Draft heading/footer code
\newcommand{\ShineDraftHeading}{%
  \RequirePackage[headsepline]{scrpage2}
  \ihead{}
  \chead[]{\fbox{\textsf\bfseries DRAFT}}
  \ohead{}
  \ifoot{\dateandtime}
  \cfoot{}
  \ofoot{\thepage}
  \pagestyle{scrheadings}
}

% Include fancier header and footer for auxiliary material document
\ifADOC@auxmat
  \RequirePackage[headsepline]{scrpage2}
  \chead{NA61/SHINE Collaboration -- arXiv:\ShineArXivId\ \ShineArXivCat}
  \pagestyle{scrheadings}
\fi

% BOOK, i.e. book heading/footer code
\newcommand{\ShineBookHeading}{%
  \RequirePackage[headsepline]{scrpage2}
  \ifx\ADOC@draftversion\@empty%
    \relax
  \else
    \ihead{DRAFT}
    \ifoot{\dateandtime}
  \fi
  \pagestyle{scrheadings}
}

% Length needed for parbox/minipage in title page
\newlength{\titlepageparbox}
\setlength{\titlepageparbox}{\textwidth}
%\addtolength{\titlepageparbox}{-2\fboxrule}
%\addtolength{\titlepageparbox}{-2\fboxsep}
%\addtolength{\titlepageparbox}{-9pt}
%\typeout{titlepageparbox is \the\titlepageparbox}

%-------------------------------------------------------------------------------
% Title page design
\newcommand{\ShineTitleHeader}{%
  \parbox[t][35mm]{\titlepageparbox}{%
    \parbox[b][35mm][t]{0.24\titlepageparbox}{%
      \includegraphics[height=25mm]{shinelogo.pdf}
    }
    \hspace*{\fill}
    \parbox[b][35mm][c]{0.48\titlepageparbox}{%
      \centering
        {\fontfamily{phv}\bfseries\fontsize{20}{24}\selectfont
         \ifx\ADOC@docheading\@empty
           \textsf{\ADOC@docheadingdefault}\par
         \else
           \textsf{\ADOC@docheading}\par
         \fi
        }
        \vspace*{2ex}
        % NA61/SHINE note number, if any 
        \ifx\ADOC@shinenote\@empty
          % NA61/SHINE reference code, if any and no note number given
          \ifx\ADOC@refcode\@empty
            \mbox{}%
          \else 
            {\Large \ADOC@refcode}\par
          \fi
        \else
          {\Large \ADOC@shinenote}\par
        \fi
        %\vspace*{2ex}
        % Date, if any
        %\ifx\@date\@empty
        %  \mbox{}\par
        %\else
        %  \@date\par
        %\fi
    }
    \hspace*{\fill}
    \parbox[b][35mm][t]{0.24\titlepageparbox}{%
      \hspace*{\fill}\includegraphics[height=25mm]{cernlogo}\par
      \ifx\ADOC@draftversion\@empty
        \relax
      \else
        \normalsize\hspace*{\fill}Draft version \ADOC@draftversion
      \fi
    }
  }\par
}

%-------------------------------------------------------------------------------
% CERN preprint title header
\newcommand{\CERNPreprintTitleHeader}{%
  \parbox[t]{\linewidth}{%
    {\centering
      \fontfamily{phv}\fontseries{m}\fontsize{14}{16.8}\selectfont
      EUROPEAN ORGANISATION FOR NUCLEAR RESEARCH (CERN)\par
    }
    \vspace*{2mm}
    \parbox[t]{0.45\linewidth}{%
      \includegraphics[height=25mm]{shinelogo.pdf}\par
      \fontfamily{phv}\fontseries{m}\fontsize{11}{13.2}\selectfont
      \ifx\ADOC@journalref\@empty
        \ifx\ADOC@journal\@empty
          \relax
        \else
          Submitted to: \ADOC@journal\par
        \fi
      \else
          \ADOC@journalref\par
      \fi
      \ifx\ADOC@doi\@empty
        \relax
      \else
        DOI: \href{http://dx.doi.org/\ADOC@doi}{\ADOC@doi}\par
      \fi
    }
    \hspace*{\fill}
    \parbox[t]{0.45\linewidth}{%
      \hspace*{\fill}\includegraphics[height=25mm]{cernlogo}\par
      \fontfamily{phv}\fontseries{m}\fontsize{11}{13.2}\selectfont
      \hspace*{\fill}\ADOC@preprintnumber\par
      \hspace*{\fill}\ADOC@shinedate\par
    }\par
    \vspace*{2mm}
    \rule{\linewidth}{1pt}\par
  }
}

%-------------------------------------------------------------------------------
% Auxiliary material title header
\newcommand{\AuxmatTitleHeader}{%
  \parbox[t]{\linewidth}{%
    {\centering
      \fontfamily{phv}\fontseries{m}\fontsize{14}{16.8}\selectfont 
      EUROPEAN ORGANISATION FOR NUCLEAR RESEARCH (CERN)\par
    }
    \vspace*{2mm}
    \parbox[t]{0.45\linewidth}{%
      \includegraphics[height=25mm]{shinelogo.pdf}\par
      \fontfamily{phv}\fontseries{m}\fontsize{11}{13.2}\selectfont 
      arXiv: \ShineArXivId\ \ShineArXivCat
    }
    \hspace*{\fill}
    \parbox[t]{0.45\linewidth}{%
      \hspace*{\fill}\includegraphics[height=25mm]{cernlogo}\par
      \fontfamily{phv}\fontseries{m}\fontsize{11}{13.2}\selectfont 
      \hspace*{\fill}\ADOC@preprintnumber\par
      \hspace*{\fill}\ADOC@shinedate\par
    }\par
    \vspace*{2mm}
    \rule{\linewidth}{1pt}\par
  }
}

%-------------------------------------------------------------------------------
% NA61/SHINE document title body
%\newcommand{\ShineTitleBody}{%
%  {\centering
%    {\bfseries\fontsize{16}{19.2}\selectfont \@title \par}
%    \vskip 3em
%    {\large
%     \lineskip .75em
%     \begin{tabular}[t]{c}
%       \@author
%     \end{tabular}\par}
%  }\par
%  \vspace{\stretch{0.5}}
%  % Astract
%  \if\ShineAbstractText\@empty
%    \mbox{}
%  \else
%    {\centering
%      \bfseries\fontsize{12}{14.4}\selectfont
%      \abstractname\par
%    }
%    {\fontseries{m}\fontsize{11}{13.2}\selectfont%
%      \begin{quote}
%        %\setlength{\parindent}{0pt}\setlength{\parskip}{0.5ex}\noindent\ShineAbstractText
%        \ShineAbstractText
%      \end{quote}
%    }
%  \fi
%  % Submission details
%  \ifx\ADOC@journal\@empty
%    \relax
%  \else
%    \ifADOC@PAPER
%      \vspace{\stretch{1}}
%      \parbox[c]{\linewidth}{
%        \centering
%        \ADOC@subprepend\ \textit{\ADOC@journal}
%      }\par
%      \vspace{\stretch{1}}
%    \fi
%  \fi
%}

%-------------------------------------------------------------------------------
% CERN Preprint title body
%\newcommand{\CERNPreprintTitleBody}{%
%  \parbox[t]{\linewidth}{%
%    {\centering
%      \bfseries\fontsize{16}{19.2}\selectfont 
%      %\fontfamily{phv}\bfseries\fontsize{16}{19.2}\selectfont 
%      \ShineTitleText\par
%    }
%    \vspace*{6ex}
%    {\centering
%      \fontseries{m}\fontsize{12}{14.4}\selectfont
%      %\fontfamily{phv}\fontseries{m}\fontsize{12}{14.4}\selectfont
%      The NA61/SHINE Collaboration\par
%    }
%    \vspace*{6ex}
%    {\centering
%      \bfseries\fontsize{12}{14.4}\selectfont
%      %\fontfamily{phv}\bfseries\fontsize{12}{14.4}\selectfont
%      \abstractname\par
%    }
%    {\fontseries{m}\fontsize{11}{13.2}\selectfont%
%      %\fontfamily{phv}\fontseries{m}\fontsize{11}{13.2}\selectfont%
%      \begin{quote}
%      %\setlength{\parindent}{0pt}\setlength{\parskip}{0.5ex}\noindent\ShineAbstractText
%        \ShineAbstractText
%      \end{quote}
%    }
%  }
%}

%-------------------------------------------------------------------------------
% Auxiliary material title body
%\newcommand{\AuxmatTitleBody}{%
%  \parbox[t]{\linewidth}{%
%    {\centering
%      \bfseries\fontsize{16}{19.2}\selectfont 
%      %\fontfamily{phv}\bfseries\fontsize{16}{19.2}\selectfont 
%      Auxiliary figures and tables related to the paper\\[1.5ex]
%      \ShineTitleText\par
%    }
%    \vspace*{2ex}
%    {\centering
%      \fontseries{m}\fontsize{12}{14.4}\selectfont
%      %\fontfamily{phv}\fontseries{m}\fontsize{12}{14.4}\selectfont
%      The NA61/SHINE Collaboration\par
%    }
%    \vspace*{2ex}
%    {\centering
%      \fontseries{m}\fontsize{12}{14.4}\selectfont
%      %\fontfamily{phv}\fontseries{m}\fontsize{12}{14.4}\selectfont
%      \ADOC@refcode\par
%    }
%    \vspace*{2ex}
%    {\centering
%      \bfseries\fontsize{12}{14.4}\selectfont
%      %\fontfamily{phv}\bfseries\fontsize{12}{14.4}\selectfont
%      \abstractname\par
%    }
%    {\centering
%      \fontseries{m}\fontsize{11}{13.2}\selectfont%
%      %\fontfamily{phv}\fontseries{m}\fontsize{11}{13.2}\selectfont%
%      \begin{quote}
%      %\setlength{\parindent}{0pt}\setlength{\parskip}{0.5ex}\noindent\ShineAbstractText
%        \ShineAbstractText
%      \end{quote}
%    }
%  }
%}

%-------------------------------------------------------------------------------
% Copyright cover footer - parbox does not introduce spurious vertical space
\newcommand{\ShineCopyrightFooter}{%
  \parbox[b]{\linewidth}{%
    \fontseries{m}\fontsize{10}{12}\selectfont
    %\fontfamily{phv}\fontseries{m}\fontsize{10}{12}\selectfont
    \copyright\ \the\year \ CERN for the benefit of the NA61/SHINE Collaboration.\newline
    Reproduction of this article or parts of it is allowed as specified in the CC-BY-4.0 license.
  }\par
}

% Add elements to KOMA-Script title page
% Header
\ifADOC@cernpreprint
  \typeout{na61doc: defining CERN preprint title page}
  \titlehead{\CERNPreprintTitleHeader}
  \date{}%\vspace*{-5ex}}
\else
  \ifADOC@auxmat
    \typeout{na61doc: defining Auxiliary Material title page}
    \titlehead{\AuxmatTitleHeader}
    \date{}%\vspace*{-5ex}}
  \else
    \typeout{na61doc: defining NA61/SHINE document title page}
    \titlehead{\ShineTitleHeader}
  \fi
\fi

% Body and copyright
\newlength{\abstractparbox}
\setlength{\abstractparbox}{\textwidth}
%\addtolength{\abstractparbox}{-2\fboxrule}
%\addtolength{\abstractparbox}{-2\fboxsep}
\newlength{\abstractheight}
\setlength{\abstractheight}{0.45\textheight}
\addtolength{\abstractheight}{-\ADOC@titleextraheight}
\newlength{\copyrightoffset}
\setlength{\copyrightoffset}{-6em}
\addtolength{\copyrightoffset}{\ADOC@copyrightoffset}
\newcommand{\ShineAbstractCopyright}{%
  \begin{minipage}[b][\abstractheight]{\abstractparbox}
    % Astract
    \if\ShineAbstractText\@empty
      \mbox{}
    \else
      \begin{quote}
      \ifx\ADOC@draftversion\@empty%
        \ShineAbstractText\par
      \else
        \begin{internallinenumbers}
          \ShineAbstractText
        \end{internallinenumbers}\par
      \fi
      \end{quote}
    \fi
    %\vspace*{\stretch{1}}
    % Submission details
    \ifx\ADOC@journal\@empty
      \relax
    \else
      \ifADOC@PAPER
        \vskip 2em
        \parbox[c]{\linewidth}{
          \centering
          \ADOC@subprepend\ \textit{\ADOC@journal}
        }\par
        \vskip 2em
      \fi
    \fi
    \vspace*{\stretch{1}}
    \ShineCopyrightFooter
  \end{minipage}\par
  \vspace*{\copyrightoffset}
}

\publishers{\normalsize\rmfamily\ShineAbstractCopyright}

\AtBeginDocument{%
  % Cover pages - add here, so shinecover options work
  \ifADOC@coverpage
    \extratitle{%
      % Turn line numbers off for cover pages
      \nolinenumbers
      \ACOV@PrintShineCover
      \ACOV@PrintShineCoverPageTwo
      % Turn line numbers back on
      \ifx\ADOC@draftversion\@empty%
        \relax
      \else
        \linenumbers
      \fi
    }
  \fi
  % Add heading for books (i.e. TDR)
  \ifADOC@BOOK
    \ShineBookHeading
    % Add draft heading and line numbers
    \ifx\ADOC@draftversion\@empty%
      \typeout{na61doc: this is not an NA61/SHINE draft book}
    \else 
      \typeout{na61doc: this is an NA61/SHINE draft book}
      \linenumbers
    \fi
  \else
    % Add draft heading and line numbers
    \ifx\ADOC@draftversion\@empty%
      \typeout{na61doc: this is not an NA61/SHINE draft article}
    \else 
      \typeout{na61doc: this is an NA61/SHINE draft article}
      \ShineDraftHeading
      \linenumbers
    \fi
  \fi
}

\endinput
